#' dtComb: A Comprehensive R Library for Combining Diagnostic Tests
#'
#' The dtComb package calculates combination scores of two biomarkers given
#' under four main categories: linear combinations with the linComb function,
#' non-linear combinations with the nonlinComb function,
#' mathematical operators with the mathComb function, and machine learning
#' algorithms with the mlComb function.
#'
#' @docType package
#' @name dtComb
"_PACKAGE"
